@@ -3,6 +3,8 @@
  *
  * Copyright (C) 2008 David Zeuthen <davidz@redhat.com>
  *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -334,7 +336,6 @@ complete_dbus_send (char *str)
   char **tokens;
   int num_tokens;
   const char *cur;
-  const char *prev;
   gboolean have_system;
   gboolean have_session;
   gboolean have_print_reply;
@@ -354,15 +355,10 @@ complete_dbus_send (char *str)
 
   tokens = g_strsplit (str, " ", 0);
   num_tokens = g_strv_length (tokens);
-  if (num_tokens >= 2) {
+  if (num_tokens >= 1) {
     cur = tokens[num_tokens - 1];
-    prev = tokens[num_tokens - 2];
-  } else if (num_tokens == 1) {
-    cur = tokens[num_tokens - 1];
-    prev = "";
   } else {
     cur = "";
-    prev = "";
   }
 
   have_system = have_option (tokens, "--system");
