@@ -3,6 +3,8 @@
  *
  * Copyright (C) 2003, 2004 Red Hat, Inc.
  *
+ * SPDX-License-Identifier: AFL-2.1 OR GPL-2.0-or-later
+ *
  * Licensed under the Academic Free License version 2.1
  *
  * This program is free software; you can redistribute it and/or modify
@@ -137,7 +139,7 @@ pretty_print (BaseInfo *base,
         g_assert (name != NULL);
 
 	annotations = method_info_get_annotations (m);
-        printf ("method \"%s\"", name);
+        printf ("method \"%s\" (\n", name);
 	for (elt = annotations; elt; elt = elt->next)
 	  {
 	    const char *name = elt->data;
