@@ -3,6 +3,8 @@
  *
  * Copyright (C) 2003, 2005  Red Hat, Inc.
  *
+ * SPDX-License-Identifier: AFL-2.1 OR GPL-2.0-or-later
+ *
  * Licensed under the Academic Free License version 2.1
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -30,6 +32,8 @@
 #include "dbus/dbus-signature.h"
 #include <string.h>
 
+#include <gio/gio.h>
+
 #define ELEMENT_IS(name) (strcmp (element_name, (name)) == 0)
 
 typedef struct
@@ -92,9 +96,6 @@ locate_attributes (const char  *element_name,
 
   va_end (args);
 
-  if (!retval)
-    return retval;
-
   i = 0;
   while (attribute_names[i])
     {
@@ -355,6 +356,14 @@ parse_interface (Parser      *parser,
       return FALSE;
     }
 
+  if (!g_dbus_is_interface_name (name))
+    {
+      g_set_error (error, G_MARKUP_ERROR,
+                   G_MARKUP_ERROR_PARSE,
+                   "\"%s\" is not a valid D-Bus interface name", name);
+      return FALSE;
+    }
+
   top = parser->node_stack->data;
   
   iface = interface_info_new (name);
@@ -407,6 +416,14 @@ parse_method (Parser      *parser,
       return FALSE;
     }
 
+  if (!g_dbus_is_member_name (name))
+    {
+      g_set_error (error, G_MARKUP_ERROR,
+                   G_MARKUP_ERROR_PARSE,
+                   "\"%s\" is not a valid D-Bus member name", name);
+      return FALSE;
+    }
+
   method = method_info_new (name);
   interface_info_add_method (parser->interface, method);
   method_info_unref (method);
@@ -457,6 +474,14 @@ parse_signal (Parser      *parser,
       return FALSE;
     }
 
+  if (!g_dbus_is_member_name (name))
+    {
+      g_set_error (error, G_MARKUP_ERROR,
+                   G_MARKUP_ERROR_PARSE,
+                   "\"%s\" is not a valid D-Bus member name", name);
+      return FALSE;
+    }
+
   signal = signal_info_new (name);
   interface_info_add_signal (parser->interface, signal);
   signal_info_unref (signal);
@@ -565,7 +590,15 @@ parse_property (Parser      *parser,
                    access, element_name);
       return FALSE;
     }
-  
+
+  if (!g_utf8_validate (name, -1, NULL))
+    {
+      g_set_error (error, G_MARKUP_ERROR,
+                   G_MARKUP_ERROR_PARSE,
+                   "\"%s\" is not UTF-8", name);
+      return FALSE;
+    }
+
   property = property_info_new (name, type, access_flags);
   interface_info_add_property (parser->interface, property);
   property_info_unref (property);
