@@ -4,6 +4,8 @@
  * Copyright (C) 2004 Ximian, Inc.
  * Copyright (C) 2005 Red Hat, Inc.
  *
+ * SPDX-License-Identifier: AFL-2.1 OR GPL-2.0-or-later
+ *
  * Licensed under the Academic Free License version 2.1
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -36,6 +38,14 @@
 /* Seems reasonable, but this should probably be part of the standard protocol */
 #define DBUS_GLIB_MAX_VARIANT_RECURSION 32
 
+static GType
+deprecated_value_array_type (void)
+{
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  return g_value_array_get_type ();
+  G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
 static gboolean demarshal_static_variant (DBusGValueMarshalCtx    *context,
 					  DBusMessageIter         *iter,
 					  GValue                  *value,
@@ -365,6 +375,9 @@ _dbus_g_value_types_init (void)
  * %DBUS_TYPE_G_OBJECT_PATH, but did not actually exist as a typedef.
  *
  * Since: 0.FIXME
+ *
+ * Deprecated: New code should use GDBus instead. The closest equivalent
+ *  is a #GVariant (%G_TYPE_VARIANT) of type %G_VARIANT_TYPE_OBJECT_PATH.
  */
 
 /**
@@ -377,6 +390,9 @@ _dbus_g_value_types_init (void)
  * stored in a #GValue.
  *
  * Returns: a type derived from %G_TYPE_BOXED
+ *
+ * Deprecated: New code should use GDBus instead. The closest equivalent
+ *  is a #GVariant (%G_TYPE_VARIANT) of type %G_VARIANT_TYPE_OBJECT_PATH.
  */
 GType
 dbus_g_object_path_get_g_type (void)
@@ -400,6 +416,9 @@ dbus_g_object_path_get_g_type (void)
  * %DBUS_TYPE_G_SIGNATURE, but did not actually exist as a typedef.
  *
  * Since: 0.FIXME
+ *
+ * Deprecated: New code should use GDBus instead. The closest equivalent
+ *  is a #GVariant (%G_TYPE_VARIANT) of type %G_VARIANT_TYPE_SIGNATURE.
  */
 
 /**
@@ -412,6 +431,9 @@ dbus_g_object_path_get_g_type (void)
  * stored in a #GValue.
  *
  * Returns: a type derived from %G_TYPE_BOXED
+ *
+ * Deprecated: New code should use GDBus instead. The closest equivalent
+ *  is a #GVariant (%G_TYPE_VARIANT) of type %G_VARIANT_TYPE_SIGNATURE.
  */
 GType
 dbus_g_signature_get_g_type (void)
@@ -492,7 +514,7 @@ _dbus_gvalue_to_signature (const GValue *val)
   GType gtype;
 
   gtype = G_VALUE_TYPE (val);
-  if (g_type_is_a (gtype, G_TYPE_VALUE_ARRAY))
+  if (g_type_is_a (gtype, deprecated_value_array_type ()))
     {
       GString *str;
       guint i;
@@ -504,7 +526,9 @@ _dbus_gvalue_to_signature (const GValue *val)
       for (i = 0; i < array->n_values; i++)
 	{
 	  char *sig;
+	  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	  sig = _dbus_gvalue_to_signature (g_value_array_get_nth (array, i));
+	  G_GNUC_END_IGNORE_DEPRECATIONS
 	  g_string_append (str, sig);
 	  g_free (sig);
 	}
@@ -531,11 +555,11 @@ demarshal_basic (DBusGValueMarshalCtx      *context,
     {
     case DBUS_TYPE_BOOLEAN:
       {
-	dbus_bool_t bool;
+	dbus_bool_t b;
         if (!G_VALUE_HOLDS (value, G_TYPE_BOOLEAN))
           goto invalid_type;
-	dbus_message_iter_get_basic (iter, &bool);
-	g_value_set_boolean (value, bool);
+	dbus_message_iter_get_basic (iter, &b);
+	g_value_set_boolean (value, b);
 	return TRUE;
       }
     case DBUS_TYPE_BYTE:
@@ -647,17 +671,24 @@ demarshal_static_variant (DBusGValueMarshalCtx    *context,
   sig = dbus_message_iter_get_signature (&subiter);
 
   variant_type = _dbus_gtype_from_signature (sig, context->proxy != NULL);
-  if (variant_type != G_TYPE_INVALID)
+  if (variant_type == G_TYPE_INVALID)
     {
-      g_value_init (value, variant_type);
-
-      if (!_dbus_gvalue_demarshal (context, &subiter, value, error))
-	{
-	  dbus_free (sig);
-	  return FALSE;
-	}
+      /* It can happen if we received an unknown type such as
+       * DBUS_TYPE_UNIX_FD or DBUS_TYPE_MAYBE. */
+      g_set_error (error, DBUS_GERROR,
+                   DBUS_GERROR_INVALID_SIGNATURE,
+                   "Variant contains unknown signature \'%s\'", sig);
+      dbus_free (sig);
+      return FALSE;
     }
+
   dbus_free (sig);
+
+  g_value_init (value, variant_type);
+
+  if (!_dbus_gvalue_demarshal (context, &subiter, value, error))
+    return FALSE;
+
   return TRUE;
 }
 
@@ -874,7 +905,9 @@ demarshal_valuearray (DBusGValueMarshalCtx    *context,
 
   dbus_message_iter_recurse (iter, &subiter);
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   ret = g_value_array_new (12);
+  G_GNUC_END_IGNORE_DEPRECATIONS
 
   while ((current_type = dbus_message_iter_get_arg_type (&subiter)) != DBUS_TYPE_INVALID)
     {
@@ -882,15 +915,19 @@ demarshal_valuearray (DBusGValueMarshalCtx    *context,
       GType elt_type; 
       char *current_sig;
 
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       g_value_array_append (ret, NULL);
       val = g_value_array_get_nth (ret, ret->n_values - 1);
+      G_GNUC_END_IGNORE_DEPRECATIONS
 
       current_sig = dbus_message_iter_get_signature (&subiter);
       elt_type = _dbus_gtype_from_signature (current_sig, TRUE);
 
       if (elt_type == G_TYPE_INVALID)
 	{
+	  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	  g_value_array_free (ret);
+	  G_GNUC_END_IGNORE_DEPRECATIONS
 	  g_set_error (error,
 		       DBUS_GERROR,
 		       DBUS_GERROR_INVALID_ARGS,
@@ -904,7 +941,9 @@ demarshal_valuearray (DBusGValueMarshalCtx    *context,
 
       if (!_dbus_gvalue_demarshal (context, &subiter, val, error))
 	{
+	  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	  g_value_array_free (ret);
+	  G_GNUC_END_IGNORE_DEPRECATIONS
 	  return FALSE;
 	}
 
@@ -1077,7 +1116,7 @@ get_type_demarshaller (GType type)
   typedata = g_type_get_qdata (type, dbus_g_type_metadata_data_quark ());
   if (typedata == NULL)
     {
-      if (g_type_is_a (type, G_TYPE_VALUE_ARRAY))
+      if (g_type_is_a (type, deprecated_value_array_type ()))
 	return demarshal_valuearray;
       if (dbus_g_type_is_collection (type))
 	return demarshal_collection;
@@ -1278,7 +1317,9 @@ _dbus_gvalue_demarshal_message  (DBusGValueMarshalCtx    *context,
   int current_type;
   guint index_;
   
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   ret = g_value_array_new (6);  /* 6 is a typical maximum for arguments */
+  G_GNUC_END_IGNORE_DEPRECATIONS
 
   dbus_message_iter_init (message, &iter);
   index_ = 0;
@@ -1295,8 +1336,10 @@ _dbus_gvalue_demarshal_message  (DBusGValueMarshalCtx    *context,
 	  goto lose;
 	}
       
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       g_value_array_append (ret, NULL);
       value = g_value_array_get_nth (ret, index_);
+      G_GNUC_END_IGNORE_DEPRECATIONS
 
       gtype = types[index_]; 
       g_value_init (value, gtype);
@@ -1316,7 +1359,9 @@ _dbus_gvalue_demarshal_message  (DBusGValueMarshalCtx    *context,
 
   return ret;
  lose:
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   g_value_array_free (ret);
+  G_GNUC_END_IGNORE_DEPRECATIONS
   return NULL;
 }
 
@@ -1338,7 +1383,7 @@ marshal_basic (DBusMessageIter *iter, const GValue *value)
     {
     case G_TYPE_CHAR:
       {
-        char b = g_value_get_char (value);
+        char b = g_value_get_schar (value);
         if (!dbus_message_iter_append_basic (iter,
                                              DBUS_TYPE_BYTE,
                                              &b))
@@ -1516,7 +1561,7 @@ marshal_valuearray (DBusMessageIter   *iter,
   guint i;
   DBusMessageIter subiter;
 
-  g_assert (G_VALUE_TYPE (value) == G_TYPE_VALUE_ARRAY);
+  g_assert (G_VALUE_TYPE (value) == deprecated_value_array_type ());
 
   array = g_value_get_boxed (value);
 
@@ -1530,11 +1575,13 @@ marshal_valuearray (DBusMessageIter   *iter,
     {
       for (i = 0; i < array->n_values; i++)
         {
+          G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           if (!_dbus_gvalue_marshal (&subiter, g_value_array_get_nth (array, i)))
             {
               dbus_message_iter_abandon_container (iter, &subiter);
               return FALSE;
             }
+          G_GNUC_END_IGNORE_DEPRECATIONS
         }
     }
 
@@ -1825,7 +1872,7 @@ get_type_marshaller (GType type)
   typedata = g_type_get_qdata (type, dbus_g_type_metadata_data_quark ());
   if (typedata == NULL)
     {
-      if (g_type_is_a (type, G_TYPE_VALUE_ARRAY))
+      if (g_type_is_a (type, deprecated_value_array_type ()))
 	return marshal_valuearray;
       if (dbus_g_type_is_collection (type))
 	return marshal_collection;
@@ -2007,15 +2054,15 @@ assert_type_maps_to (GType gtype, const char *expected_sig)
 {
   char *sig;
   sig = _dbus_gtype_to_signature (gtype);
-  g_assert (sig != NULL);
-  g_assert (!strcmp (expected_sig, sig));
+  g_assert_nonnull (sig);
+  g_assert_cmpstr (expected_sig, ==, sig);
   g_free (sig);
 }
 
 static void
 assert_signature_maps_to (const char *sig, GType expected_gtype)
 {
-  g_assert (_dbus_gtype_from_signature (sig, TRUE) == expected_gtype);
+  g_assert_cmpuint (_dbus_gtype_from_signature (sig, TRUE), ==, expected_gtype);
 }
 
 static void
@@ -2027,11 +2074,15 @@ assert_bidirectional_mapping (GType gtype, const char *expected_sig)
 
 /*
  * Unit test for general glib stuff
- * Returns: #TRUE on success.
+ * Returns: %TRUE on success.
  */
 gboolean
 _dbus_gvalue_test (const char *test_data_dir)
 {
+  GType type;
+  GType rectype;
+
+  g_type_init ();
   _dbus_g_value_types_init ();
   
   assert_bidirectional_mapping (G_TYPE_STRING, DBUS_TYPE_STRING_AS_STRING);
@@ -2047,6 +2098,29 @@ _dbus_gvalue_test (const char *test_data_dir)
 
   assert_bidirectional_mapping (dbus_g_type_get_struct ("GValueArray", G_TYPE_INT, G_TYPE_STRING, DBUS_TYPE_G_OBJECT_PATH, G_TYPE_INVALID),
   				DBUS_STRUCT_BEGIN_CHAR_AS_STRING DBUS_TYPE_INT32_AS_STRING DBUS_TYPE_STRING_AS_STRING DBUS_TYPE_OBJECT_PATH_AS_STRING DBUS_STRUCT_END_CHAR_AS_STRING );
+
+  rectype = dbus_g_type_get_collection ("GArray", G_TYPE_UINT);
+  g_assert_cmpuint (rectype, !=, G_TYPE_INVALID);
+  g_assert_cmpstr (g_type_name (rectype), ==, "GArray_guint_");
+
+  type = _dbus_gtype_from_signature ("au", TRUE);
+  g_assert_cmpuint (type, ==, rectype);
+
+  rectype = dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING);
+  g_assert_cmpuint (rectype, !=, G_TYPE_INVALID);
+  g_assert_cmpstr (g_type_name (rectype), ==, "GHashTable_gchararray+gchararray_");
+
+  type = _dbus_gtype_from_signature ("a{ss}", TRUE);
+  g_assert_cmpuint (type, ==, rectype);
+
+  type = _dbus_gtype_from_signature ("o", FALSE);
+  g_assert_cmpuint (type, ==, DBUS_TYPE_G_OBJECT_PATH);
+  type = _dbus_gtype_from_signature ("o", TRUE);
+  g_assert_cmpuint (type, ==, DBUS_TYPE_G_OBJECT_PATH);
+
+  type = _dbus_gtype_from_signature ("g", TRUE);
+  g_assert_cmpuint (type, ==, DBUS_TYPE_G_SIGNATURE);
+
   return TRUE;
 }
 
